@@ -44,7 +44,7 @@ class ErioonClient:
             print(f"[ErioonClient] Initialization error: {e}")
 
     def _perform_login(self):
-        url = f"{self.base_url}/login"
+        url = f"{self.base_url}/login_sdk"
         payload = {"api_key": self.api, "email": self.email, "password": self.password}
         headers = {"Content-Type": "application/json"}
 
