@@ -20,8 +20,6 @@ from erioon.create import handle_insert_one, handle_insert_many
 from erioon.delete import handle_delete_one, handle_delete_many
 from erioon.update import handle_update_one, handle_update_many, handle_replace_one
 from erioon.ping import handle_connection_ping
-from erioon.vector import handle_vector_similarity_search
-# from erioon.ai import handle_deep_search
 
 class Collection:
     def __init__(
@@ -489,7 +487,6 @@ class Collection:
         )
 
         if status != 200 or not response or "record" not in response:
-            # fallback to 'id'
             search_criteria = [{"id": _id}]
             response, status = handle_find_one(
                 user_id=self.user_id,
@@ -509,73 +506,6 @@ class Collection:
 
         return record
 
-    def vector_similarity_search(self, query_vector, similarity_metric='cosine', limit=100):
-        """
-        Perform a vector similarity search within this collection.
-
-        Args:
-            query_vector (list[float]): The query vector to compare against.
-            similarity_metric (str): Similarity metric, 'cosine' (default) or 'euclidean'.
-            limit (int): Max number of results to return (default: 10).
-
-        Returns:
-            dict: Search results with similarity scores.
-        """
-        if self._is_read_only():
-            return self._read_only_response()
-
-        # Call the centralized handler function
-        result, status = handle_vector_similarity_search(
-            user_id=self.user_id,
-            db_id=self.db_id,
-            coll_id=self.coll_id,
-            query_vector=query_vector,
-            similarity_metric=similarity_metric,
-            limit=limit,
-            container_url=self.container_url,
-        )
-
-        if status == 200:
-            print(f"Vector similarity search returned {result.get('count', 0)} results.")
-        else:
-            print(f"Vector similarity search error: {result.get('error', 'Unknown error')}")
-
-        return result, status
-
-    
-    # # DEEP AI-POWERED SEARCH (GPT-4)
-    # def deep_search(self, model: str, api_key: str, question: str, limit: int = 10000):
-    #     """
-    #     Perform an AI-powered search over the collection using a natural language query.
-
-    #     Args:
-    #         model (str): OpenAI model to use, e.g., "gpt-4" or "gpt-4o".
-    #         api_key (str): OpenAI API key.
-    #         question (str): Natural language query, e.g., "Find all AAPL stocks above 200".
-    #         limit (int): Max number of records to load before filtering (default: 10,000).
-
-    #     Returns:
-    #         dict: {
-    #             "answer": <AI explanation>,
-    #             "filtered": <matching JSON records>
-    #         }
-    #     """
-    #     self._print_loading()
-
-    #     result = handle_deep_search(
-    #         user_id=self.user_id,
-    #         db_id=self.db_id,
-    #         coll_id=self.coll_id,
-    #         question=question,
-    #         model=model,
-    #         api_key=api_key,
-    #         limit=limit,
-    #         container_url=self.container_url,
-    #     )
-
-    #     return result
-
-
 
     def __str__(self):
         """Pretty print the collection metadata."""
