@@ -17,6 +17,7 @@ import io
 import msgpack
 from azure.storage.blob import ContainerClient
 from erioon.functions import async_log
+import re
 
 # GET ALL RECORDS OF A COLLECTION
 def handle_get_all(user_id, db_id, coll_id, limit, container_url):
@@ -252,10 +253,13 @@ def handle_find_many(user_id, db_id, coll_id, search_criteria, limit, container_
     async_log(user_id, db_id, coll_id, "GET_MANY", "ERROR", "No matching records found", 1, container_url)
     return {"status": "KO", "count": 0, "error": "No matching records found"}, 404
 
-# COUNT ALL THE RECORDS
+
+# COUNT ALL THE RECORDS - Optimized with shard logic
 def handle_count_records(user_id, db_id, coll_id, container_url):
     """
     Count all records stored as .msgpack files in a given collection in Azure Blob Storage.
+    Assumes all shards except the last one contain exactly 100,000 records.
+    Shards must follow the naming pattern: <coll_id>_<shard_number>.msgpack
 
     Args:
         user_id (str): ID of the user making the request.
@@ -266,40 +270,69 @@ def handle_count_records(user_id, db_id, coll_id, container_url):
     Returns:
         tuple: (total_record_count: int, status_code: int)
     """
-    import msgpack
-    from azure.storage.blob import ContainerClient
-
+    
+    MAX_RECORDS_PER_SHARD = 100_000
     directory_path = f"{db_id}/{coll_id}/"
     container_client = ContainerClient.from_container_url(container_url)
 
+    shard_pattern = re.compile(rf"{re.escape(directory_path)}{re.escape(coll_id)}_(\d+)\.msgpack$")
+
     try:
         blob_list = container_client.list_blobs(name_starts_with=directory_path)
-        blob_names = [blob.name for blob in blob_list if blob.name.endswith(".msgpack")]
+        shard_blobs = []
+        for blob in blob_list:
+            match = shard_pattern.match(blob.name)
+            if match:
+                shard_index = int(match.group(1))
+                shard_blobs.append((shard_index, blob.name))
+
+        if not shard_blobs:
+            async_log(user_id, db_id, coll_id, "COUNT", "ERROR",
+                      f"No valid shard files found for collection {coll_id}.", 0, container_url)
+            return 0, 404
+
+        shard_blobs.sort(key=lambda x: x[0])
     except Exception as e:
-        async_log(user_id, db_id, coll_id, "COUNT", "ERROR", f"Blob listing failed: {str(e)}", 0, container_url)
+        async_log(user_id, db_id, coll_id, "COUNT", "ERROR",
+                  f"Blob listing failed: {str(e)}", 0, container_url)
         return 0, 500
 
-    if not blob_names:
-        async_log(user_id, db_id, coll_id, "COUNT", "ERROR", f"No collection {coll_id} found.", 0, container_url)
-        return 0, 404
+    total_shards = len(shard_blobs)
 
-    total_count = 0
+    expected_indices = list(range(total_shards))
+    actual_indices = [index for index, _ in shard_blobs]
+    if actual_indices != expected_indices:
+        async_log(user_id, db_id, coll_id, "COUNT", "ERROR",
+                  f"Shard sequence is not continuous: {actual_indices}", 0, container_url)
+        return 0, 500
 
-    for blob_name in blob_names:
+    if total_shards == 1:
         try:
-            blob_client = container_client.get_blob_client(blob_name)
+            blob_client = container_client.get_blob_client(shard_blobs[0][1])
             msgpack_data = blob_client.download_blob().readall()
-
-            if msgpack_data:
-                records = msgpack.unpackb(msgpack_data, raw=False)
-                if isinstance(records, list):
-                    total_count += len(records)
-                else:
-                    # Optional: warn on unexpected format
-                    continue
+            records = msgpack.unpackb(msgpack_data, raw=False)
+            record_count = len(records) if isinstance(records, list) else 0
+            async_log(user_id, db_id, coll_id, "COUNT", "SUCCESS",
+                      f"Total records: {record_count}", record_count, container_url)
+            return record_count, 200
         except Exception as e:
-            # Optional: log per-blob error if needed
-            continue
+            async_log(user_id, db_id, coll_id, "COUNT", "ERROR",
+                      f"Failed to read shard: {str(e)}", 0, container_url)
+            return 0, 500
 
-    async_log(user_id, db_id, coll_id, "COUNT", "SUCCESS", f"Total records: {total_count}", total_count, container_url)
+    try:
+        last_blob_name = shard_blobs[-1][1]
+        blob_client = container_client.get_blob_client(last_blob_name)
+        msgpack_data = blob_client.download_blob().readall()
+        records = msgpack.unpackb(msgpack_data, raw=False)
+        last_shard_count = len(records) if isinstance(records, list) else 0
+    except Exception as e:
+        async_log(user_id, db_id, coll_id, "COUNT", "ERROR",
+                  f"Failed to read last shard: {str(e)}", 0, container_url)
+        return 0, 500
+
+    total_count = (total_shards - 1) * MAX_RECORDS_PER_SHARD + last_shard_count
+
+    async_log(user_id, db_id, coll_id, "COUNT", "SUCCESS",
+              f"Total records: {total_count}", total_count, container_url)
     return total_count, 200
